@@ -5,6 +5,7 @@ from advpowcommon.ui.Cachers import DITPixbufCacher
 from advpowcommon.ui.Animation import DITPBCachedAnimator
 from advpowcommon.ui.ToggleControl import ToggleControlMaemo5
 from advpowcommon.util.execn import *
+from advifswlib.util.cacher import *
 from advifswlib.util.config import *
 from advifswlib.util.locale import *
 
@@ -37,7 +38,7 @@ class AbstractInterface():
     self.__button.connect('tap-and-hold', self.__button_tap_and_hold)
     self.__button.connect('destroy', self.__destroy)
 
-    self.__smi_cacher = DITPixbufCacher(48)
+    self.__smi_cacher = get_cacher()
     self.__smi_animator = DITPBCachedAnimator([], self.__button.get_image().set_from_pixbuf, cacher=self.__smi_cacher, time_out=250)
 
     self.state_control = None
