@@ -70,25 +70,21 @@ class WLANInterface(AbstractInterface):
       gobject.idle_add(self.run_commands, self.wifi_turn_on_cmd)
     elif self.state['value'] == 2:
       try:
-        self.get_interface('ICD').disconnect_req(dbus.UInt32(32768))
+        self.get_interface('ICD').disconnect_req(dbus.UInt32(0x8000))
       except:
         self.reinit_interface('ICD')
         #self.get_interface('ICD').disconnect_req(dbus.UInt32(32768))
 
   def turn_off(self):
     if self.state['value'] > 0:
-      cmd = []
       if self.state['value'] == 2:
         try:
-          #cmd.append("dbus-send --print-reply --system --dest=com.nokia.icd2 /com/nokia/icd2 com.nokia.icd2.disconnect_req uint32:0x8000")
           self.get_interface('ICD').disconnect_req(dbus.UInt32(0x8000))
         except:
           self.reinit_interface('ICD')
           #self.get_interface('ICD').disconnect_req(dbus.UInt32(32768))
-          #pass
       #run_async(self.run_commands, (self.wifi_turn_off_cmd,))
-      cmd.extend(self.wifi_turn_off_cmd)
-      gobject.idle_add(self.run_commands, cmd)
+      gobject.idle_add(self.run_commands, self.wifi_turn_off_cmd)
 
   def run_commands(self, cmds):
     run_shell_command(' && '.join(cmds))
@@ -99,8 +95,7 @@ class WLANInterface(AbstractInterface):
     try:
       self.get_interface('ICD').scan_req(dbus.UInt32(0), dbus.Array([], signature='s'))
     except:
-      pass
-      #self.reinit_interface('ICD')
+      self.reinit_interface('ICD')
       #self.get_interface('ICD').scan_req(dbus.UInt32(0), dbus.Array([], signature='s'))
 
   def get_strength(self):
